@@ -64,24 +64,24 @@ class SCollection : public QObject {
  private:
   void SyncPlaycountAndRatingToFiles();
 
- public slots:
+ public Q_SLOTS:
   void ReloadSettings();
 
   void PauseWatcher();
   void ResumeWatcher();
 
   void FullScan();
-  void AbortScan();
+  void StopScan();
   void Rescan(const SongList &songs);
 
   void IncrementalScan();
 
- private slots:
+ private Q_SLOTS:
   void ExitReceived();
   void SongsPlaycountChanged(const SongList &songs, const bool save_tags = false);
   void SongsRatingChanged(const SongList &songs, const bool save_tags = false);
 
- signals:
+ Q_SIGNALS:
   void Error(const QString &error);
   void ExitFinished();
 
