@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2019-2023, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2019-2024, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 #include "albumcoverimageresult.h"
 
 class QThread;
+class QTimer;
 class QNetworkReply;
 class NetworkAccessManager;
 
@@ -59,7 +60,7 @@ class AlbumCoverLoader : public QObject {
   void CancelTask(const quint64 id);
   void CancelTasks(const QSet<quint64> &ids);
 
- signals:
+ Q_SIGNALS:
   void ExitFinished();
   void AlbumCoverLoaded(const quint64 id, const AlbumCoverLoaderResult &result);
 
@@ -117,14 +118,15 @@ class AlbumCoverLoader : public QObject {
   LoadImageResult LoadRemoteUrlImage(TaskPtr task, const AlbumCoverLoaderResult::Type result_type, const QUrl &cover_url);
   void FinishTask(TaskPtr task, const AlbumCoverLoaderResult::Type result_type);
 
- private slots:
+ private Q_SLOTS:
   void Exit();
+  void StartProcessTasks();
   void ProcessTasks();
   void LoadRemoteImageFinished(QNetworkReply *reply, AlbumCoverLoader::TaskPtr task, const AlbumCoverLoaderResult::Type result_type, const QUrl &cover_url);
 
  private:
-  static const int kMaxRedirects = 3;
   SharedPtr<NetworkAccessManager> network_;
+  QTimer *timer_process_tasks_;
   bool stop_requested_;
   QMutex mutex_load_image_async_;
   QQueue<TaskPtr> tasks_;
