@@ -49,9 +49,10 @@
 #include "equalizerslider.h"
 #include "ui_equalizer.h"
 
-const char *Equalizer::kGainText[] = { "60", "170", "310", "600", "1k", "3k", "6k", "12k", "14k", "16k" };
-
-const char *Equalizer::kSettingsGroup = "Equalizer";
+namespace {
+constexpr char kSettingsGroup[] = "Equalizer";
+const char *kGainText[] = { "60", "170", "310", "600", "1k", "3k", "6k", "12k", "14k", "16k" };
+}  // namespace
 
 Equalizer::Equalizer(QWidget *parent)
     : QDialog(parent),
@@ -184,7 +185,7 @@ void Equalizer::PresetChanged(const QString &name) {
   }
   last_preset_ = name;
 
-  Params &p = presets_[name];
+  const Params p = presets_.value(name);
 
   loading_ = true;
   preamp_->set_value(p.preamp);
@@ -290,24 +291,24 @@ void Equalizer::StereoBalancerEnabledChangedSlot(const bool enabled) {
 
   if (!enabled) {
     ui_->stereo_balance_slider->setValue(0);
-    emit StereoBalanceChanged(stereo_balance());
+    Q_EMIT StereoBalanceChanged(stereo_balance());
   }
   ui_->stereo_balance_slider->setEnabled(enabled);
-  emit StereoBalancerEnabledChanged(enabled);
+  Q_EMIT StereoBalancerEnabledChanged(enabled);
   Save();
 
 }
 
 void Equalizer::StereoBalanceSliderChanged(const int) {
 
-  emit StereoBalanceChanged(stereo_balance());
+  Q_EMIT StereoBalanceChanged(stereo_balance());
   Save();
 
 }
 
 void Equalizer::EqualizerEnabledChangedSlot(const bool enabled) {
 
-  emit EqualizerEnabledChanged(enabled);
+  Q_EMIT EqualizerEnabledChanged(enabled);
   ui_->slider_container->setEnabled(enabled);
   Save();
 
@@ -316,7 +317,7 @@ void Equalizer::EqualizerEnabledChangedSlot(const bool enabled) {
 void Equalizer::EqualizerParametersChangedSlot() {
 
   if (loading_) return;
-  emit EqualizerParametersChanged(preamp_value(), gain_values());
+  Q_EMIT EqualizerParametersChanged(preamp_value(), gain_values());
 
 }
 
@@ -328,7 +329,7 @@ void Equalizer::Save() {
   // Presets
   s.beginWriteArray("presets", static_cast<int>(presets_.count()));
   int i = 0;
-  QStringList presets = presets_.keys();
+  const QStringList presets = presets_.keys();
   for (const QString &name : presets) {
     s.setArrayIndex(i++);
     s.setValue("name", name);
