@@ -66,14 +66,9 @@ class Organize : public QObject {
   explicit Organize(SharedPtr<TaskManager> task_manager, SharedPtr<MusicStorage> destination, const OrganizeFormat &format, const bool copy, const bool overwrite, const bool albumcover, const NewSongInfoList &songs, const bool eject_after, const QString &playlist = QString(), QObject *parent = nullptr);
   ~Organize() override;
 
-  static const int kBatchSize;
-#ifdef HAVE_GSTREAMER
-  static const int kTranscodeProgressInterval;
-#endif
-
   void Start();
 
- signals:
+ Q_SIGNALS:
   void Finished(const QStringList &files_with_errors, const QStringList&);
   void FileCopied(const int database_id);
   void SongPathChanged(const Song &song, const QFileInfo &new_file, const std::optional<int> new_collection_directory_id);
@@ -81,7 +76,7 @@ class Organize : public QObject {
  protected:
   void timerEvent(QTimerEvent *e) override;
 
- private slots:
+ private Q_SLOTS:
   void ProcessSomeFiles();
   void FileTranscoded(const QString &input, const QString &output, bool success);
   void LogLine(const QString &message);
