@@ -54,9 +54,6 @@ class PlaylistTabBar : public QTabBar {
  public:
   explicit PlaylistTabBar(QWidget *parent = nullptr);
 
-  static const int kDragHoverTimeout = 500;
-  static const char *kSettingsGroup;
-
   void SetActions(QAction *new_playlist, QAction *load_playlist);
   void SetManager(SharedPtr<PlaylistManager> manager);
 
@@ -73,7 +70,7 @@ class PlaylistTabBar : public QTabBar {
   void RemoveTab(const int id);
   void InsertTab(const int id, const int index, const QString &text, const bool favorite);
 
- signals:
+ Q_SIGNALS:
   void CurrentIdChanged(const int id);
   void Rename(const int id, const QString &name);
   void Close(const int id);
@@ -92,7 +89,7 @@ class PlaylistTabBar : public QTabBar {
   void timerEvent(QTimerEvent *e) override;
   bool event(QEvent *e) override;
 
- private slots:
+ private Q_SLOTS:
   void CurrentIndexChanged(const int index);
   void RenameSlot();
   void RenameInline();
