@@ -53,10 +53,10 @@ class RadioService : public QObject {
   virtual QUrl Homepage() = 0;
   virtual QUrl Donate() = 0;
 
- signals:
+ Q_SIGNALS:
   void NewChannels(const RadioChannelList &channels = RadioChannelList());
 
- public slots:
+ public Q_SLOTS:
   virtual void GetChannels() = 0;
 
  protected:
