@@ -19,6 +19,8 @@
 
 #include "config.h"
 
+#include <utility>
+
 #include <QObject>
 #include <QList>
 #include <QByteArray>
@@ -141,20 +143,20 @@ void TidalRequest::LoginComplete(const bool success, const QString &error) {
 void TidalRequest::Process() {
 
   if (!service_->authenticated()) {
-    emit UpdateStatus(query_id_, tr("Authenticating..."));
+    Q_EMIT UpdateStatus(query_id_, tr("Authenticating..."));
     need_login_ = true;
     service_->TryLogin();
     return;
   }
 
   switch (query_type_) {
-    case Type::Artists:
+    case Type::FavouriteArtists:
       GetArtists();
       break;
-    case Type::Albums:
+    case Type::FavouriteAlbums:
       GetAlbums();
       break;
-    case Type::Songs:
+    case Type::FavouriteSongs:
       GetSongs();
       break;
     case Type::SearchArtists:
@@ -224,8 +226,8 @@ void TidalRequest::Search(const int query_id, const QString &search_text) {
 
 void TidalRequest::GetArtists() {
 
-  emit UpdateStatus(query_id_, tr("Receiving artists..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Receiving artists..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddArtistsRequest();
 
 }
@@ -254,7 +256,7 @@ void TidalRequest::FlushArtistsRequests() {
     if (request.limit > 0) parameters << Param(QStringLiteral("limit"), QString::number(request.limit));
     if (request.offset > 0) parameters << Param(QStringLiteral("offset"), QString::number(request.offset));
     QNetworkReply *reply = nullptr;
-    if (query_type_ == Type::Artists) {
+    if (query_type_ == Type::FavouriteArtists) {
       reply = CreateRequest(QStringLiteral("users/%1/favorites/artists").arg(service_->user_id()), parameters);
     }
     if (query_type_ == Type::SearchArtists) {
@@ -272,8 +274,8 @@ void TidalRequest::FlushArtistsRequests() {
 
 void TidalRequest::GetAlbums() {
 
-  emit UpdateStatus(query_id_, tr("Receiving albums..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Receiving albums..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddAlbumsRequest();
 
 }
@@ -302,7 +304,7 @@ void TidalRequest::FlushAlbumsRequests() {
     if (request.limit > 0) parameters << Param(QStringLiteral("limit"), QString::number(request.limit));
     if (request.offset > 0) parameters << Param(QStringLiteral("offset"), QString::number(request.offset));
     QNetworkReply *reply = nullptr;
-    if (query_type_ == Type::Albums) {
+    if (query_type_ == Type::FavouriteAlbums) {
       reply = CreateRequest(QStringLiteral("users/%1/favorites/albums").arg(service_->user_id()), parameters);
     }
     if (query_type_ == Type::SearchAlbums) {
@@ -320,8 +322,8 @@ void TidalRequest::FlushAlbumsRequests() {
 
 void TidalRequest::GetSongs() {
 
-  emit UpdateStatus(query_id_, tr("Receiving songs..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Receiving songs..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddSongsRequest();
 
 }
@@ -350,7 +352,7 @@ void TidalRequest::FlushSongsRequests() {
     if (request.limit > 0) parameters << Param(QStringLiteral("limit"), QString::number(request.limit));
     if (request.offset > 0) parameters << Param(QStringLiteral("offset"), QString::number(request.offset));
     QNetworkReply *reply = nullptr;
-    if (query_type_ == Type::Songs) {
+    if (query_type_ == Type::FavouriteSongs) {
       reply = CreateRequest(QStringLiteral("users/%1/favorites/tracks").arg(service_->user_id()), parameters);
     }
     if (query_type_ == Type::SearchSongs) {
@@ -368,8 +370,8 @@ void TidalRequest::FlushSongsRequests() {
 
 void TidalRequest::ArtistsSearch() {
 
-  emit UpdateStatus(query_id_, tr("Searching..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Searching..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddArtistsSearchRequest();
 
 }
@@ -382,8 +384,8 @@ void TidalRequest::AddArtistsSearchRequest(const int offset) {
 
 void TidalRequest::AlbumsSearch() {
 
-  emit UpdateStatus(query_id_, tr("Searching..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Searching..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddAlbumsSearchRequest();
 
 }
@@ -396,8 +398,8 @@ void TidalRequest::AddAlbumsSearchRequest(const int offset) {
 
 void TidalRequest::SongsSearch() {
 
-  emit UpdateStatus(query_id_, tr("Searching..."));
-  emit UpdateProgress(query_id_, 0);
+  Q_EMIT UpdateStatus(query_id_, tr("Searching..."));
+  Q_EMIT UpdateProgress(query_id_, 0);
   AddSongsSearchRequest();
 
 }
@@ -461,7 +463,7 @@ void TidalRequest::ArtistsReplyReceived(QNetworkReply *reply, const int limit_re
   }
 
   if (offset_requested == 0) {
-    emit UpdateProgress(query_id_, GetProgress(artists_received_, artists_total_));
+    Q_EMIT UpdateProgress(query_id_, GetProgress(artists_received_, artists_total_));
   }
 
   QJsonValue value_items = ExtractItems(json_obj);
@@ -470,14 +472,14 @@ void TidalRequest::ArtistsReplyReceived(QNetworkReply *reply, const int limit_re
     return;
   }
 
-  QJsonArray array_items = value_items.toArray();
+  const QJsonArray array_items = value_items.toArray();
   if (array_items.isEmpty()) {  // Empty array means no results
     ArtistsFinishCheck();
     return;
   }
 
   int artists_received = 0;
-  for (const QJsonValueRef value_item : array_items) {
+  for (const QJsonValue &value_item : array_items) {
 
     ++artists_received;
 
@@ -519,7 +521,7 @@ void TidalRequest::ArtistsReplyReceived(QNetworkReply *reply, const int limit_re
   }
   artists_received_ += artists_received;
 
-  if (offset_requested != 0) emit UpdateProgress(query_id_, GetProgress(artists_received_, artists_total_));
+  if (offset_requested != 0) Q_EMIT UpdateProgress(query_id_, GetProgress(artists_received_, artists_total_));
 
   ArtistsFinishCheck(limit_requested, offset, artists_received);
 
@@ -532,7 +534,7 @@ void TidalRequest::ArtistsFinishCheck(const int limit, const int offset, const i
   if ((limit == 0 || limit > artists_received) && artists_received_ < artists_total_) {
     int offset_next = offset + artists_received;
     if (offset_next > 0 && offset_next < artists_total_) {
-      if (query_type_ == Type::Artists) AddArtistsRequest(offset_next);
+      if (query_type_ == Type::FavouriteArtists) AddArtistsRequest(offset_next);
       else if (query_type_ == Type::SearchArtists) AddArtistsSearchRequest(offset_next);
     }
   }
@@ -540,16 +542,16 @@ void TidalRequest::ArtistsFinishCheck(const int limit, const int offset, const i
   if (artists_requests_queue_.isEmpty() && artists_requests_active_ <= 0) {  // Artist query is finished, get all albums for all artists.
 
     // Get artist albums
-    QList<ArtistAlbumsRequest> requests = artist_albums_requests_pending_.values();
+    const QList<ArtistAlbumsRequest> requests = artist_albums_requests_pending_.values();
     for (const ArtistAlbumsRequest &request : requests) {
       AddArtistAlbumsRequest(request.artist);
     }
     artist_albums_requests_pending_.clear();
 
     if (artist_albums_requests_total_ > 0) {
-      if (artist_albums_requests_total_ == 1) emit UpdateStatus(query_id_, tr("Receiving albums for %1 artist...").arg(artist_albums_requests_total_));
-      else emit UpdateStatus(query_id_, tr("Receiving albums for %1 artists...").arg(artist_albums_requests_total_));
-      emit UpdateProgress(query_id_, 0);
+      if (artist_albums_requests_total_ == 1) Q_EMIT UpdateStatus(query_id_, tr("Receiving albums for %1 artist...").arg(artist_albums_requests_total_));
+      else Q_EMIT UpdateStatus(query_id_, tr("Receiving albums for %1 artists...").arg(artist_albums_requests_total_));
+      Q_EMIT UpdateProgress(query_id_, 0);
     }
 
   }
@@ -601,7 +603,7 @@ void TidalRequest::ArtistAlbumsReplyReceived(QNetworkReply *reply, const Artist
 
   --artist_albums_requests_active_;
   ++artist_albums_requests_received_;
-  emit UpdateProgress(query_id_, GetProgress(artist_albums_requests_received_, artist_albums_requests_total_));
+  Q_EMIT UpdateProgress(query_id_, GetProgress(artist_albums_requests_received_, artist_albums_requests_total_));
   AlbumsReceived(reply, artist, 0, offset_requested, false);
 
 }
@@ -652,14 +654,14 @@ void TidalRequest::AlbumsReceived(QNetworkReply *reply, const Artist &artist_req
     AlbumsFinishCheck(artist_requested);
     return;
   }
-  QJsonArray array_items = value_items.toArray();
+  const QJsonArray array_items = value_items.toArray();
   if (array_items.isEmpty()) {
     AlbumsFinishCheck(artist_requested);
     return;
   }
 
   int albums_received = 0;
-  for (const QJsonValueRef value_item : array_items) {
+  for (const QJsonValue &value_item : array_items) {
 
     ++albums_received;
 
@@ -766,9 +768,9 @@ void TidalRequest::AlbumsReceived(QNetworkReply *reply, const Artist &artist_req
 
   }
 
-  if (query_type_ == Type::Albums || query_type_ == Type::SearchAlbums) {
+  if (query_type_ == Type::FavouriteAlbums || query_type_ == Type::SearchAlbums) {
     albums_received_ += albums_received;
-    emit UpdateProgress(query_id_, GetProgress(albums_received_, albums_total_));
+    Q_EMIT UpdateProgress(query_id_, GetProgress(albums_received_, albums_total_));
   }
 
   AlbumsFinishCheck(artist_requested, limit_requested, offset, albums_total, albums_received);
@@ -783,13 +785,13 @@ void TidalRequest::AlbumsFinishCheck(const Artist &artist, const int limit, cons
     int offset_next = offset + albums_received;
     if (offset_next > 0 && offset_next < albums_total) {
       switch (query_type_) {
-        case Type::Albums:
+        case Type::FavouriteAlbums:
           AddAlbumsRequest(offset_next);
           break;
         case Type::SearchAlbums:
           AddAlbumsSearchRequest(offset_next);
           break;
-        case Type::Artists:
+        case Type::FavouriteArtists:
         case Type::SearchArtists:
           AddArtistAlbumsRequest(artist, offset_next);
           break;
@@ -810,16 +812,16 @@ void TidalRequest::AlbumsFinishCheck(const Artist &artist, const int limit, cons
 
     // Get songs for all the albums.
 
-    for (QHash<QString, AlbumSongsRequest>::iterator it = album_songs_requests_pending_.begin(); it != album_songs_requests_pending_.end(); ++it) {
+    for (QHash<QString, AlbumSongsRequest>::const_iterator it = album_songs_requests_pending_.constBegin(); it != album_songs_requests_pending_.constEnd(); ++it) {
       const AlbumSongsRequest &request = it.value();
       AddAlbumSongsRequest(request.artist, request.album);
     }
     album_songs_requests_pending_.clear();
 
     if (album_songs_requests_total_ > 0) {
-      if (album_songs_requests_total_ == 1) emit UpdateStatus(query_id_, tr("Receiving songs for %1 album...").arg(album_songs_requests_total_));
-      else emit UpdateStatus(query_id_, tr("Receiving songs for %1 albums...").arg(album_songs_requests_total_));
-      emit UpdateProgress(query_id_, 0);
+      if (album_songs_requests_total_ == 1) Q_EMIT UpdateStatus(query_id_, tr("Receiving songs for %1 album...").arg(album_songs_requests_total_));
+      else Q_EMIT UpdateStatus(query_id_, tr("Receiving songs for %1 albums...").arg(album_songs_requests_total_));
+      Q_EMIT UpdateProgress(query_id_, 0);
     }
   }
 
@@ -877,7 +879,7 @@ void TidalRequest::AlbumSongsReplyReceived(QNetworkReply *reply, const Artist &a
   --album_songs_requests_active_;
   ++album_songs_requests_received_;
   if (offset_requested == 0) {
-    emit UpdateProgress(query_id_, GetProgress(album_songs_requests_received_, album_songs_requests_total_));
+    Q_EMIT UpdateProgress(query_id_, GetProgress(album_songs_requests_received_, album_songs_requests_total_));
   }
   SongsReceived(reply, artist, album, 0, offset_requested, false);
 
@@ -930,7 +932,7 @@ void TidalRequest::SongsReceived(QNetworkReply *reply, const Artist &artist, con
     return;
   }
 
-  QJsonArray array_items = json_value.toArray();
+  const QJsonArray array_items = json_value.toArray();
   if (array_items.isEmpty()) {
     SongsFinishCheck(artist, album, limit_requested, offset_requested, songs_total, 0);
     return;
@@ -940,7 +942,7 @@ void TidalRequest::SongsReceived(QNetworkReply *reply, const Artist &artist, con
   bool multidisc = false;
   SongList songs;
   int songs_received = 0;
-  for (const QJsonValueRef value_item : array_items) {
+  for (const QJsonValue &value_item : array_items) {
 
     if (!value_item.isObject()) {
       Error(QStringLiteral("Invalid Json reply, track is not a object."));
@@ -966,15 +968,15 @@ void TidalRequest::SongsReceived(QNetworkReply *reply, const Artist &artist, con
     songs << song;
   }
 
-  for (Song song : songs) {
+  for (Song song : std::as_const(songs)) {
     if (compilation) song.set_compilation_detected(true);
     if (!multidisc) song.set_disc(0);
     songs_.insert(song.song_id(), song);
   }
 
-  if (query_type_ == Type::Songs || query_type_ == Type::SearchSongs) {
+  if (query_type_ == Type::FavouriteSongs || query_type_ == Type::SearchSongs) {
     songs_received_ += songs_received;
-    emit UpdateProgress(query_id_, GetProgress(songs_received_, songs_total_));
+    Q_EMIT UpdateProgress(query_id_, GetProgress(songs_received_, songs_total_));
   }
 
   SongsFinishCheck(artist, album, limit_requested, offset_requested, songs_total, songs_received);
@@ -989,7 +991,7 @@ void TidalRequest::SongsFinishCheck(const Artist &artist, const Album &album, co
     int offset_next = offset + songs_received;
     if (offset_next > 0 && offset_next < songs_total) {
       switch (query_type_) {
-        case Type::Songs:
+        case Type::FavouriteSongs:
           AddSongsRequest(offset_next);
           break;
         case Type::SearchSongs:
@@ -999,9 +1001,9 @@ void TidalRequest::SongsFinishCheck(const Artist &artist, const Album &album, co
             break;
           }
           [[fallthrough]];
-        case Type::Artists:
+        case Type::FavouriteArtists:
         case Type::SearchArtists:
-        case Type::Albums:
+        case Type::FavouriteAlbums:
         case Type::SearchAlbums:
           AddAlbumSongsRequest(artist, album, offset_next);
           break;
@@ -1194,9 +1196,9 @@ void TidalRequest::GetAlbumCovers() {
     AddAlbumCoverRequest(song);
   }
 
-  if (album_covers_requests_total_ == 1) emit UpdateStatus(query_id_, tr("Receiving album cover for %1 album...").arg(album_covers_requests_total_));
-  else emit UpdateStatus(query_id_, tr("Receiving album covers for %1 albums...").arg(album_covers_requests_total_));
-  emit UpdateProgress(query_id_, 0);
+  if (album_covers_requests_total_ == 1) Q_EMIT UpdateStatus(query_id_, tr("Receiving album cover for %1 album...").arg(album_covers_requests_total_));
+  else Q_EMIT UpdateStatus(query_id_, tr("Receiving album covers for %1 albums...").arg(album_covers_requests_total_));
+  Q_EMIT UpdateProgress(query_id_, 0);
 
   StartRequests();
 
@@ -1257,7 +1259,7 @@ void TidalRequest::AlbumCoverReceived(QNetworkReply *reply, const QString &album
 
   if (finished_) return;
 
-  emit UpdateProgress(query_id_, GetProgress(album_covers_requests_received_, album_covers_requests_total_));
+  Q_EMIT UpdateProgress(query_id_, GetProgress(album_covers_requests_received_, album_covers_requests_total_));
 
   if (!album_covers_requests_sent_.contains(album_id)) {
     AlbumCoverFinishCheck();
@@ -1300,7 +1302,7 @@ void TidalRequest::AlbumCoverReceived(QNetworkReply *reply, const QString &album
   QByteArrayList format_list = QImageReader::imageFormatsForMimeType(mimetype.toUtf8());
   char *format = nullptr;
   if (!format_list.isEmpty()) {
-    format = format_list.first().data();
+    format = format_list[0].data();
   }
 
   QImage image;
@@ -1361,18 +1363,18 @@ void TidalRequest::FinishCheck() {
     if (songs_.isEmpty()) {
       if (errors_.isEmpty()) {
         if (IsSearch()) {
-          emit Results(query_id_, SongMap(), tr("No match."));
+          Q_EMIT Results(query_id_, SongMap(), tr("No match."));
         }
         else {
-          emit Results(query_id_);
+          Q_EMIT Results(query_id_);
         }
       }
       else {
-        emit Results(query_id_, SongMap(), ErrorsToHTML(errors_));
+        Q_EMIT Results(query_id_, SongMap(), ErrorsToHTML(errors_));
       }
     }
     else {
-      emit Results(query_id_, songs_);
+      Q_EMIT Results(query_id_, songs_);
     }
   }
 
