@@ -48,6 +48,7 @@ class VolumeSlider : public SliderSlider {
  public:
   explicit VolumeSlider(QWidget *parent, uint max = 0);
   void SetEnabled(const bool enabled);
+  void HandleWheel(const int delta);
 
  protected:
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
@@ -63,13 +64,16 @@ class VolumeSlider : public SliderSlider {
   void mousePressEvent(QMouseEvent*) override;
   void wheelEvent(QWheelEvent *e) override;
 
- private slots:
+ private Q_SLOTS:
   virtual void slotAnimTimer();
 
  private:
   static const int ANIM_INTERVAL = 18;
   static const int ANIM_MAX = 18;
 
+  // Units are eighths of a degree
+  static const int WHEEL_ROTATION_PER_STEP = 30;
+
   VolumeSlider(const VolumeSlider&);
   VolumeSlider &operator=(const VolumeSlider&);
 
@@ -77,6 +81,8 @@ class VolumeSlider : public SliderSlider {
   QPixmap drawVolumePixmap() const;
   void drawVolumeSliderHandle();
 
+  int wheel_accumulator_;
+
   bool anim_enter_;
   int anim_count_;
   QTimer *timer_anim_;
